//functions abstracted from our core Data requests
//these are platform-dependent portions of code which
// set incoming data into their respective UI elements
// ...the WU Data parts are platform-independent

//bool which tells us to display or not to display the alert on show/hides
var alert_displayed = false;

function setAlert(alerts) {
	var url = prefs.getNiceUrl();
	
	var alBackground = document.getElementById('alert_background');
	var alMessage = document.getElementById('alertMessage');
	alMessage.onclick = null;
	
	var only_non_crucial = true;
	var alert_string = "";
	var critical_type = null;
	
	for(var i = 0; i < alerts.length; i++) {
	  al = alerts[i];
	  if (al.type != "REP" && al.type != "PUB" && al.type != "REC") {
	    only_non_crucial = false; critical_type = al.type;
	  }
	  alert_string += al.description + ": " + al.longSummary;
	}
	
	if (Widget_upgradeAlert != null) {
    al = Widget_upgradeAlert;
	  alert_string += al.description + ": " + al.longSummary;
	}
	
	//not crucial information
	if (only_non_crucial == true && (alerts.length > 0 || Widget_upgradeAlert != null)) {
		alBackground.src = "Images/gui/alertBlue.png";
		alMessage.innerHTML = alert_string;
		alMessage.style.color = "#222";
		setAlertDisplay("");
		alert_displayed = true;
		
		if (Widget_upgradeAlert != null) {
		  alMessage.onclick = linkTo(Widget_upgradeAlert.url);
		} else {
  		alMessage.onclick = linkTo("http://www.wunderground.com" + url + "#" + (critical_type || alerts[0].type));  
		}	
		
	} else if (alerts.length > 0) {
		alBackground.src = "Images/gui/alert.png";
		alMessage.innerHTML = alert_string;
		alMessage.style.color = "#fff";
		setAlertDisplay("");
		alert_displayed = true;
		
		alMessage.onclick = linkTo("http://www.wunderground.com" + url + "#" + (critical_type || alerts[0].type));
	} else {
		alert_displayed = false;
		setAlertDisplay('none');
	}
}

function setAlertDisplay(display) {
	var alertMessage = document.getElementById('alertMessage');
	alertMessage.style.display = display;
	var alertBackground = document.getElementById('alert_background');
	alertBackground.style.display = display;
}

function Widget_setRadarDisplay(display) {
	var radar = document.getElementById('radar');
	radar.style.display = display;
}

function Widget_createWebcamImage(webcam) {
  var wunderimage = document.getElementById('wundercamImage');
  
  wimg = document.createElement("img");
  wimg.style.visibility = 'visible';
  wimg.id = 'wundercamImage';
  wimg.src = webcam.url.match(/^(.+time=)/)[1] + now();
  wimg.onclick = linkTo(webcam.camUrl);
  $('wundercamTitle').innerHTML = webcam.city+ " <em>(" + webcam.handle + ")</em>";
  
  wunderimage.parentNode.replaceChild(wimg,wunderimage);
}

function setWebcamsAndRadar(l) {
	//WEBCAMS
	var wunderTab = document.getElementById('wundercamTab');
	var wundercamSelect = document.getElementById('wundercamSelect');
	
	if (l.webcams.length > 0) {
		
		wunderTab.style.visibility = "visible";
		Widget_createWebcamImage(l.webcams[0]);
		
		if (l.webcams.length > 1) {
			var webcamSelect = new Array();
			for(var i = 0; i < l.webcams.length; i++) webcamSelect.push({'name':l.webcams[i].city+ " (" + l.webcams[i].handle + ")"});
			makeSelectBox('wundercamSelect',webcamSelect,Widget_changeWebcam);
			$('wundercamSelectButton').style.display = "";
		} else {
		  
		  prefs.setWebcam(0);
			wundercamSelect.innerHTML = null;
			wundercamSelect.disabled = true;
			$('wundercamSelectButton').style.display = "none";
		}
		
	} else {
	  
	  prefs.setWebcam(null);
		wundercamSelect.innerHTML = null;
		wundercamSelect.disabled = true;
		$('wundercamSelectButton').style.display = "none";
		
		wunderTab.style.visibility = "hidden";
		if ($('wundercam').style.visibility == 'visible') {
		  Widget_rightSetContent('conditions',true);
	  }
		
	}
	
	
	//RADAR
	$('radar').src = (l.radar.image ? l.radar.image : RADAR_BLANK);
	
	if (!l.radar.image) {
		
		if ($('radar').style.visibility == 'visible') {
		  Widget_rightSetContent('conditions',true);
	  }
		$('radarTab').style.visibility = "hidden";

	} else {
		
		$('radarTab').style.visibility = "visible";
		
		$('radar').style.border = "1px solid black";
	}
	
	if ($('radarTab').style.visibility == 'hidden' && wunderTab.style.visibility == 'hidden') {
		$('conditionsTab').style.visibility = "hidden";
	} else {
		$('conditionsTab').style.visibility = "visible";
	}
	
	if (l.radar.url != null) {
		$('radar').onclick = linkTo(l.radar.url);
	}
	
}

function setForecast(fcst) {

	/**
	 * Text forecasts, obtained from the NWS or put together from our information
	 */
	var txt;
	
	if (fcst.txtFcsts.length > 0) {
		$('forecast_date').innerHTML = (fcst.txtFcsts[0].title ? fcst.txtFcsts[0].title : "Today");
		$('forecast_time').innerHTML = (fcst.txtFcstDate ? "as of " + fcst.txtFcstDate : "");

		if (fcst.txtFcsts[0].text != null && fcst.txtFcsts[0].text != "--" ) { 
			txt = (fcst.txtFcsts[0].text + " " +
					(fcst.txtFcsts[1].title ? fcst.txtFcsts[1].title : "Later") + ": " +
					fcst.txtFcsts[1].text);
			$('text').innerHTML = txt;
			var a = document.createElement('a');
			a.setAttribute('id',"moreForecast");
			addEvent(a,"click",linkTo(loc.wuiurl));
			a.appendChild(document.createTextNode("more"));
			$('text').appendChild(a);
		} else {
			$('text').innerHTML = "";
		}
	} else {
		$('forecast_date').innerHTML = "Today";
		$('forecast_time').innerHTML = (fcst.txtFcstDate ? "as of " + fcst.txtFcstDate : "");
	}
	
	/*
	 * MINIMIZED FORECAST, only appears when the widget is minimized
	 */
	if (fcst.weekFcsts.length > 0) {
		$('minimized_day').innerHTML = weekDay(fcst.weekFcsts[0].day);
		$('minimized_high').innerHTML = unitData(fcst.weekFcsts[0].high,"bigTemp");
		$('minimized_low').innerHTML = unitData(fcst.weekFcsts[0].low,"bigTemp");
		$('minimized_icon').src = SM_ICON_DIR + (fcst.weekFcsts[0].icon ? fcst.weekFcsts[0].icon: SM_ICON_BLANK) + ICON_FILE_TYPE;
	}
	
	//WEEK FORECAST
	var max = 6;
	var len = fcst.weekFcsts.length; var times;
	var unit;

	//moves fourcast icons based on their number
	Widget_putColCSS(len % 2 != 0 ? 28 : 0);

	if (len == 4 || len == 3) {
		times = 1;
	} else if (len == 2 || len == 1) {
		times = 2;
	} else {
		times = 0;
	}
	for(var i = 0; i < times; i++) {//fill in missing dates
		document.getElementById('high'+i).innerHTML = "";
		document.getElementById('low'+i).innerHTML = "";
		document.getElementById('pic'+i).src = SM_ICON_DIR + SM_ICON_BLANK + ICON_FILE_TYPE;
		document.getElementById('day'+i).innerHTML = ""; 	
	}

	var j = 0;
	for(var i = times; j < len && i < max; i++) {
		document.getElementById('day'+i).innerHTML = weekDay(fcst.weekFcsts[j].day);
		document.getElementById('high'+i).innerHTML = unitData(fcst.weekFcsts[j].high,"bigTemp");
		document.getElementById('low'+i).innerHTML = unitData(fcst.weekFcsts[j].low,"bigTemp");
		document.getElementById('pic'+i).src = SM_ICON_DIR + (fcst.weekFcsts[j].icon ? fcst.weekFcsts[j].icon: SM_ICON_BLANK) + ICON_FILE_TYPE;
		++j;
	}
	for(var i = (max-1); i > (len - 1 + times); i--) {//fill in missing dates
		document.getElementById('high'+i).innerHTML = "";
		document.getElementById('low'+i).innerHTML = "";
		document.getElementById('pic'+i).src = SM_ICON_DIR + SM_ICON_BLANK + ICON_FILE_TYPE;
		document.getElementById('day'+i).innerHTML = ""; 	
	}
	
}

function setCurConds (cur_conds, no_overwrite, type) {
	var windchill;
	var heatindex;
	var wind;
	var temp;
	var dewpoint;
	var visibility;	
	var pressure;

  if (type == 'airport') {
  	if (cur_conds.icon != null && typeof(Forecast_forecastData) != "undefined" && Forecast_forecastData != null) {//so PWS cur conds don't overwrite our airport icon conditions
  		setWxIcon(Forecast_forecastData.moon,cur_conds.icon);
  	} else if (no_overwrite == false) {
  	  document.getElementById('wxIconOverlay').src = ICON_DIR + ICON_BLANK + ICON_FILE_TYPE;
    	document.getElementById('wxIcon').src = ICON_DIR + ICON_BLANK + ICON_FILE_TYPE;
  	}
  }

	//only run if we don't care about overwriting conditions already on the widget
	if (no_overwrite == false) {  
		if (cur_conds.conditions_full != null && cur_conds.conditions_full != "NA") {
			$('conditions_conditions').innerHTML = toCapitalCase(cur_conds.conditions_full);
		} else {
			$('conditions_conditions').innerHTML = "";
		}
	
		$('conditions_wind').innerHTML = unitData(cur_conds.wind,"wind") + " " + (cur_conds.windDirection || "");
	
		var wcTitle = $('conditions_windchillTitle'); var wc = $('conditions_windchill');
		if ((windchill = unitData(cur_conds.windchill,"temp")) != "N/A") {
			wcTitle.innerHTML = "Windchill"; wc.innerHTML = windchill;
			wcTitle.style.display = ""; wc.style.display = "";
		} else if ((heatindex = unitData(cur_conds.heatindex,"temp")) != "N/A") {
			wcTitle.innerHTML = "Heat Index"; wc.innerHTML = heatindex;
			wcTitle.style.display = ""; wc.style.display = "";		
		} else {
			wcTitle.style.display = "none";
			wc.style.display = "none";
		}
	
	  var humidity; humidity = parseInt(cur_conds.humidity,10);
		$('conditions_humidity').innerHTML = unitData([humidity,humidity],"humidity");
	
		$('conditions_dewpoint').innerHTML = unitData(cur_conds.dewpoint,"temp");
		
		$('conditions_pressure').innerHTML = unitData(cur_conds.pressure,"pressure");
	
		$('conditions_visibility').innerHTML = unitData(cur_conds.visibility,"visibility");
	
		$('temperature').innerHTML = (unitData(cur_conds.temperature,"bigTemp") != "N/A" ? unitData(cur_conds.temperature,"bigTemp") : "--&deg;");
	}
}