/** dataLib **/
/**
***		Functions that are used by the data receiving classes, but shouldn't
***		be placed in the general library
***
***
**/

//icon globals
var ICON_DIR = "Images/wxIcons/";
var SM_ICON_DIR = ICON_DIR + "small/";
var SM_ICON_BLANK = "blank";
var ICON_BLANK = "blank";
var ICON_FILE_TYPE = ".png";
var RADAR_BLANK = "Images/blank.png";
var RADAR_DIM = 130;

function linkTo(url) {
	//widget.openURL(url);
	if (window.widget)
		return (function() {widget.openURL(url);});
	else 
		return (function() {window.location = url;});
}

function weekDay(day) {
	var txt;
	
	switch(day) {
		case "Monday": txt = "MON"; break;
		case "Tuesday": txt = "TUE"; break;
		case "Wednesday": txt = "WED"; break;
		case "Thursday": txt = "THU"; break;
		case "Friday": txt = "FRI"; break;
		case "Saturday": txt = "SAT"; break;
		case "Sunday": txt = "SUN"; break;
		case "---": txt = "---"; break;
		default: txt = day; break;
	}
	return txt;
}

function unitData(element,type) {
	var myUnits = prefs.getUnits();
	var txt;
	var range;
	var unit;
	
	switch(type) {
		case "wind": unit = ["mph","kph"]; range = [0,200]; break;
		case "temp": unit = ["&deg;F","&deg;C"]; range = [-150,150]; break;
		case "bigTemp": unit = ["&deg;","&deg;"]; range = [-150,150]; break;
		case "pressure": unit = ["in","hpa"]; range = [26,33]; break;
		case "visibility": unit = ["sm","km"]; range = [0,70]; break;
		case "humidity": unit = ["%","%"]; range = [0,100]; break;
		default: unit = ["",""]; range = null; break;
	}
	
	var BAD_VALUES = ["N/A","NA","null","",null,"-9999.0","-9999"];
	
	if (typeof(element) == "object" && element.length > 0 && 
			inArray(element[0],BAD_VALUES) == false &&
			inArray(element[1],BAD_VALUES) == false && 
			(range != null && element[0] >= range[0] && element[0] <= range[1])
			) {
			  
		if (type == 'bigTemp') {element[0] = Math.round(element[0]); element[1] = Math.round(element[1]);}
		
		var spacing = (inArray(type,["bigTemp","humidity"]) == false ? " " : "");
		
		if (myUnits == 2 && type != "humidity") //both
			txt =  element[0] + (unit[0] ? spacing + unit[0] : "") + "/" + element[1] + (unit[1] ? spacing + unit[1] : "");
		else if (myUnits == 0 || type == 'humidity')
			txt = element[0] + (unit[0] ? spacing + unit[0] : "");
		else
			txt = element[1] + (unit[1] ? spacing + unit[1] : "");
	} else {
		txt = "N/A";
	}
	return txt;
}

function setWxIcon(moon,cond) {
	
	var nowHours = parseInt(moon.curHour) + (moon.curMin / 60);
	var sunset = parseInt(moon.sunsetHour) + (moon.sunsetMin / 60); 
	var sunrise = parseInt(moon.sunriseHour) + (moon.sunriseMin / 60);
	
	var overlay;
	var wxIcon;
	
	if (nowHours > sunset || nowHours < sunrise) {
	// moon conditions
		if (inArray(cond,['cloudy','mostlysunny','partlycloudy','fog','mostlycloudy','partlysunny'])) {
			overlay = "moon_overlay/"+cond;
		} else {
			overlay = null;
		}

		if (inArray(cond,['day_flurries','flurries','rain','sleet','sleat','snow','thunderstorms','tstorms'])) {
			wxIcon = cond;
		} else {
			if (moon.age >= 27 || moon.age < 3) {
				wxIcon = "moon/new";
			} else if (moon.age >= 3 && moon.age < 6) {
				wxIcon = "moon/waxingcrescent";
			} else if (moon.age >= 6 && moon.age < 10) {
				wxIcon = "moon/firstqtr";
			} else if (moon.age >= 10 && moon.age < 13) {
				wxIcon = "moon/waxinggibbous";
			} else if (moon.age >= 13 && moon.age < 16) {
				wxIcon = "moon/full";
			} else if (moon.age >= 16 && moon.age < 20) {
				wxIcon = "moon/waninggibbous";
			} else if (moon.age >= 20 && moon.age < 24) {
				wxIcon = "moon/lastqtr";
			} else if (moon.age >= 24 && moon.age < 27) {
				wxIcon = "moon/waningcrescent";
			} else { //there's some sort of problem
				wxIcon = "moon/full";
			}
		}

	} else {
	//day conditions
		overlay = null;
		wxIcon = cond;
	}
	
	document.getElementById('wxIconOverlay').src = (overlay ? ICON_DIR + overlay + ICON_FILE_TYPE : "");
	document.getElementById('wxIcon').src = (wxIcon ? ICON_DIR + wxIcon + ICON_FILE_TYPE : "");
}

function outputLocalWxStnTitle(stn) {
	return ((stn.type == "airport" ? (stn.id != "----" ? stn.id + "\: ":"") : "") +
	(stn.neighborhood ? stn.neighborhood : stn.city + ", " + (stn.state ? stn.state : "") + (stn.country != "US" ? stn.country : "")));	
}