/*

File: Fader.js

Abstract: JavaScript logic for one-off and transitional fades of DOM elements 
	Retasked to use the AppleAnimator class; simpler codebase

Version: 2.0

 Copyright 2005 Apple Computer, Inc. All rights reserved.

IMPORTANT:  This Apple software is supplied to 
you by Apple Computer, Inc. ("Apple") in 
consideration of your agreement to the following 
terms, and your use, installation, modification 
or redistribution of this Apple software 
constitutes acceptance of these terms.  If you do 
not agree with these terms, please do not use, 
install, modify or redistribute this Apple 
software.

In consideration of your agreement to abide by 
the following terms, and subject to these terms, 
Apple grants you a personal, non-exclusive 
license, under Apple's copyrights in this 
original Apple software (the "Apple Software"), 
to use, reproduce, modify and redistribute the 
Apple Software, with or without modifications, in 
source and/or binary forms; provided that if you 
redistribute the Apple Software in its entirety 
and without modifications, you must retain this 
notice and the following text and disclaimers in 
all such redistributions of the Apple Software. 
Neither the name, trademarks, service marks or 
logos of Apple Computer, Inc. may be used to 
endorse or promote products derived from the 
Apple Software without specific prior written 
permission from Apple.  Except as expressly 
stated in this notice, no other rights or 
licenses, express or implied, are granted by 
Apple herein, including but not limited to any 
patent rights that may be infringed by your 
derivative works or by other works in which the 
Apple Software may be incorporated.

The Apple Software is provided by Apple on an "AS 
IS" basis.  APPLE MAKES NO WARRANTIES, EXPRESS OR 
IMPLIED, INCLUDING WITHOUT LIMITATION THE IMPLIED 
WARRANTIES OF NON-INFRINGEMENT, MERCHANTABILITY 
AND FITNESS FOR A PARTICULAR PURPOSE, REGARDING 
THE APPLE SOFTWARE OR ITS USE AND OPERATION ALONE 
OR IN COMBINATION WITH YOUR PRODUCTS.

IN NO EVENT SHALL APPLE BE LIABLE FOR ANY 
SPECIAL, INDIRECT, INCIDENTAL OR CONSEQUENTIAL 
DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS 
OF USE, DATA, OR PROFITS; OR BUSINESS 
INTERRUPTION) ARISING IN ANY WAY OUT OF THE USE, 
REPRODUCTION, MODIFICATION AND/OR DISTRIBUTION OF 
THE APPLE SOFTWARE, HOWEVER CAUSED AND WHETHER 
UNDER THEORY OF CONTRACT, TORT (INCLUDING 
NEGLIGENCE), STRICT LIABILITY OR OTHERWISE, EVEN 
IF APPLE HAS BEEN ADVISED OF THE POSSIBILITY OF 
SUCH DAMAGE.

*/ 


/*
 *************************************************
 * Fader object fades a single element in or out *
 *************************************************
 */
 
/*
 * Fader constructor.  Parameters:
 * - element: The element to fade in or out
 * - callback: A function that will be called when a fade is complete
 * - fadeTime: How long (in ms) the fade should take (see setFadeTime())
 */
function Fader (element, callback, fadeTime, minOpacity, maxOpacity) {
	this.element = element;
	this.isArray = (this.element.length == null ? false : true);
	
	this.onFinished = callback;
	
	// Initialize for a fade-in; these values will be reset by the fadeIn/fadeOut functions
	this.fadingIn;
	this.now = 0.0;
	this.from = 0.0;
	this.to = 1.0;
		
	this.minOpacity = minOpacity ? minOpacity : 0;
	this.maxOpacity = maxOpacity ? maxOpacity : 1;
	
	this.setFadeTime(fadeTime);
	
	var self = this;
	
	this.nextFrame = function (animation, now, first, done) {
		if (self.isArray) //if the element is really an array
			for(var i = 0; i < self.element.length; i++)
				self.element[i].style.opacity = now;
		else
		self.element.style.opacity = now;
	}
}

/* 
 * Prototype method declarations; call these methods as 
 * nameOfFaderInstance.methodName();
 */
Fader.prototype.fadeOut = function () {
	if (this.fadingIn == false) {
		return;
	}
	var from = this.maxOpacity;
	if (this.isArray ? this.element[0].style.opacity : this.element.style.opacity) {
		from = parseInt(this.isArray ? this.element[0].style.opacity : this.element.style.opacity);
	}
	this.fadeTo(from, this.minOpacity);
	this.fadingIn = false;
}

Fader.prototype.fadeIn = function () {
	if (this.fadingIn == true) {
		return;
	}
	var from = this.minOpacity;
	if (this.isArray ? this.element[0].style.opacity : this.element.style.opacity) {
		from = parseInt(this.isArray ? this.element[0].style.opacity : this.element.style.opacity);
	}
	this.fadeTo(from, this.maxOpacity);
	this.fadingIn = true;
}

Fader.prototype.fadeTo = function (newFrom, newTo) {
	if (this.fadeAnimator) {
		this.fadeAnimator.stop();
		delete this.fadeAnimator;
	}
	
	this.fadeAnimator = new AppleAnimator(this.fadeTime, 13, newFrom, newTo, this.nextFrame);
	this.fadeAnimator.oncomplete = this.onFinished;
	this.fadeAnimator.start();
}

/*
 * Setter function for fade duration (floored at 250ms)
 */
Fader.prototype.setFadeTime  = function (fadeTime) {
	this.fadeTime = fadeTime > 250 ? fadeTime : 250;
}

// End Fader object definition